@@ -17,8 +17,6 @@
  * Author: Meg Ford <megford@gnome.org>
  *
  */
- 
-imports.gi.versions.Gst = '1.0';
 
 const _ = imports.gettext.gettext;
 const Gio = imports.gi.Gio;
@@ -26,7 +24,7 @@ const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject; 
 const Gst = imports.gi.Gst;
 const GstPbutils = imports.gi.GstPbutils;
-
+const Lang = imports.lang;
 const Signals = imports.signals;
 
 const AudioProfile = imports.audioProfile;
@@ -198,7 +196,7 @@ const Listview = new Lang.Class({
                         
     _onDiscovererFinished: function(res, info, err) {
         this.result = res;
-        if (this.result == GstPbutils.DiscovererResult.OK) { 
+        if (this.result == GstPbutils.DiscovererResult.OK && allFilesInfo[this.idx]) { 
             this.tagInfo = info.get_tags(info);
             let appString = "";
             let dateTimeCreatedString = ""; 
@@ -227,6 +225,7 @@ const Listview = new Lang.Class({
             this._getCapsForList(info);
         } else {
             // don't index files we can't play
+            allFilesInfo.splice(this.idx, 1);
             log("File cannot be played");
         }
         
@@ -255,7 +254,8 @@ const Listview = new Lang.Class({
         
     _onDirChanged: function(dirMonitor, file1, file2, eventType) {
         if (eventType == Gio.FileMonitorEvent.DELETED || 
-            (eventType == Gio.FileMonitorEvent.CHANGES_DONE_HINT && MainWindow.recordPipeline == MainWindow.RecordPipelineStates.STOPPED)) {
+            (eventType == Gio.FileMonitorEvent.CHANGES_DONE_HINT 
+                && MainWindow.recordPipeline == MainWindow.RecordPipelineStates.STOPPED)) {
             stopVal = EnumeratorState.ACTIVE;
             allFilesInfo.length = 0;
             fileInfo.length = 0;
@@ -299,14 +299,12 @@ const Listview = new Lang.Class({
         } else if (audioCaps.can_intersect(this.capTypes(AudioProfile.audioCodecMap.FLAC))) {
             allFilesInfo[this.idx].mediaType = mediaTypeMap.FLAC;
                       
-        } else {
+        } 
         
-            if (allFilesInfo[this.idx].mediaType == null) {
+        if (allFilesInfo[this.idx].mediaType == null) {
                 // Remove the file from the array if we don't recognize it    
-                allFilesInfo.splice(this.idx, 1);
-        	this.endIdx = this.endIdx - 1;
-            }       
-        }        
+                allFilesInfo.splice(this.idx, 1);    
+        }      
     },
 
     capTypes: function(capString) {
