@@ -16,15 +16,16 @@
 * Author: Meg Ford <megford@gnome.org>
 *
 */
- 
-imports.gi.versions.Gst = '1.0';
 
 const Gettext = imports.gettext;
 const _ = imports.gettext.gettext;
 const Gdk = imports.gi.Gdk;
 const GdkPixbuf = imports.gi.GdkPixbuf;
 const Gio = imports.gi.Gio;
+const GLib = imports.gi.GLib;
 const Gst = imports.gi.Gst;
+const Gtk = imports.gi.Gtk;
+const Lang = imports.lang;
 const Pango = imports.gi.Pango;
 
 const Application = imports.application;
@@ -32,6 +33,7 @@ const AudioProfile = imports.audioProfile;
 const FileUtil = imports.fileUtil;
 const Info = imports.info;
 const Listview = imports.listview;
+const Params = imports.params;
 const Play = imports.play;
 const Preferences = imports.preferences;
 const Record = imports.record;
@@ -221,10 +223,10 @@ const MainView = new Lang.Class({
     presetVolume: function(source, vol) {
         if (source == ActiveArea.PLAY) {
             volumeValue[0].play = vol;
-            Application.application.setSpeakerVolume(vol);
+            Application.application.setSpeakerVolume(vol);            
         } else {
             volumeValue[0].record = vol;
-            Application.application.setMicVolume(vol);
+            Application.application.setMicVolume(vol); 
         }              
     },
     
@@ -248,7 +250,7 @@ const MainView = new Lang.Class({
         let playVolume = Application.application.getSpeakerVolume();
         let micVolume = Application.application.getMicVolume();
         volumeValue.push({ record: micVolume, play: playVolume });
-        activeProfile = AudioProfile.comboBoxMap.OGG_VORBIS;
+        activeProfile = Application.application.getPreferences();
                 
         this.recordGrid = new Gtk.Grid({ orientation: Gtk.Orientation.HORIZONTAL,
                                          height_request: 36,
